@@ -18,12 +18,18 @@ else:
     help='Base URL of the provider to verify against.',
     required=True)
 @click.option(
-    'pact_urls', '--pact-urls',
+    'pact_url', '--pact-url',
     help='The URI of the pact to verify.'
          ' Can be an HTTP URI or a local file path.'
          ' It can be specified multiple times to verify several pacts.',
-    multiple=True,
-    required=True)
+    multiple=True)
+@click.option(
+    'pact_urls', '--pact-urls',
+    default='',
+    help='The URI(s) of the pact to verify.'
+         ' Can be an HTTP URI(s) or local file path(s).'
+         ' Provide multiple URI separated by a comma.',
+    multiple=True)  # Remove in major version 1.0.0
 @click.option(
     'states_url', '--provider-states-url',
     help='URL to fetch the provider states for the given provider API.')
@@ -44,16 +50,17 @@ else:
     help='The duration in seconds we should wait to confirm verification'
          ' process was successful. Defaults to 30.',
     type=int)
-def main(base_url, pact_urls, states_url, states_setup_url, username,
+def main(base_url, pact_url, pact_urls, states_url, states_setup_url, username,
          password, timeout):
     """
     Verify one or more contracts against a provider service.
 
     Minimal example:
 
-        pact-verifier --provider-base-url=http://localhost:8080 --pact-urls=./pacts
+        pact-verifier --provider-base-url=http://localhost:8080 --pact-url=./pact
     """  # NOQA
     error = click.style('Error:', fg='red')
+    warning = click.style('Warning:', fg='yellow')
     if bool(states_url) != bool(states_setup_url):
         click.echo(
             error
@@ -61,7 +68,24 @@ def main(base_url, pact_urls, states_url, states_setup_url, username,
               ' --provider-states-url and --provider-states-setup-url.')
         raise click.Abort()
 
-    missing_files = [path for path in pact_urls if not path_exists(path)]
+    all_pact_urls = list(pact_url)
+    for urls in pact_urls:  # Remove in major version 1.0.0
+        all_pact_urls.extend(p for p in urls.split(',') if p)
+
+    if len(pact_urls) > 1:
+        click.echo(
+            warning
+            + ' Multiple --pact-urls arguments are deprecated. '
+              'Please provide a comma separated list of pacts to --pact-urls, '
+              'or multiple --pact-url arguments.')
+
+    if not all_pact_urls:
+        click.echo(
+            error
+            + ' At least one of --pact-url or --pact-urls is required.')
+        raise click.Abort()
+
+    missing_files = [path for path in all_pact_urls if not path_exists(path)]
     if missing_files:
         click.echo(
             error
@@ -71,7 +95,7 @@ def main(base_url, pact_urls, states_url, states_setup_url, username,
 
     options = {
         '--provider-base-url': base_url,
-        '--pact-urls': ','.join(pact_urls),
+        '--pact-urls': ','.join(all_pact_urls),
         '--provider-states-url': states_url,
         '--provider-states-setup-url': states_setup_url,
         '--broker-username': username,
